@@ -1,7 +1,7 @@
 //
 // bricks (4096 uncompressed bytes)
 //
-extern const unsigned char bricks_Bitmap[4096] = {
+/*extern const*/ unsigned char bricks_Bitmap[4096] = {
 0x0b, 0x0b, 0x0d, 0x05, 0x0d, 0x05, 0x05, 0x05, 0x03, 0x03, 0x0c, 0x03, 0x0f, 0x03, 0x03, 0x05, 
 0x03, 0x03, 0x05, 0x03, 0x03, 0x03, 0x03, 0x0f, 0x03, 0x0f, 0x0c, 0x0c, 0x03, 0x03, 0x0c, 0x03, 
 0x05, 0x0b, 0x0d, 0x05, 0x0d, 0x05, 0x05, 0x05, 0x03, 0x03, 0x0c, 0x03, 0x0f, 0x03, 0x03, 0x05, 
