@@ -2,10 +2,10 @@
 
 /* create the map */
 
-#define MAP_SIZE_X 16
-#define MAP_SIZE_Y 8
+#define MAP_SIZE_X 32
+#define MAP_SIZE_Y 32
 
-u8 map[] = {
+/*u8 map[] = {
 	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
 	1, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 1,
 	1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 1,
@@ -14,10 +14,13 @@ u8 map[] = {
 	1, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1,
 	1, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 1,
 	1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1};
+*/
 
-s32 px = (64 * 4);
-s32 py = (64 * 4);
-s32 pa = 0;
+#include "map.raw.c"
+
+s32 px = 400;
+s32 py = 160;
+s32 pa = 180;
 
 #define SCREEN_WIDTH 120
 #define SCREEN_HEIGHT 160
@@ -27,18 +30,10 @@ s32 pa = 0;
 #define PROJECTION_DISTANCE 208
 //#define PROJECTION_DISTANCE 104
 
-/*SDL_Color palette[] = {
-	{ 0, 0, 0, 0},
-	{ 50, 50, 50, 0},
-	{ 100, 100, 100, 0},
-	{ 200, 200, 200, 0},
-	{ 0, 0, 200, 0}
-};*/
-
-/*int pythag(float dx, float dy)
+int pythag(float dx, float dy)
 {
 	return sqrt(dx*dx + dy*dy);
-}*/
+}
 
 /*double gettimeofday_double()
 {
@@ -58,10 +53,11 @@ s32 pa = 0;
 #define MOVE_TL		1 << 4
 #define MOVE_TR		1 << 5
 
-#include "bricks.raw.c"
-#include "bricks.pal.c"
+#include "walltextures.raw.c"
+#include "walltextures.pal.c"
 
 //#define TRACE(x...) printf(x)
+//#define TRACE(x...) sprintf(foo, x); print(foo)
 #define TRACE(x...)
 
 #include "table.h"
@@ -135,7 +131,7 @@ s32 gba_tan(s32 angle)
 	
 	if(angle <= FIXED(180))
 	{
-		if(angle < FIXED(90))
+		if(angle <= FIXED(90))
 		{
 			res = tan_table[angle >> 6];
 		} else {
@@ -159,14 +155,14 @@ void asm_rasterise_line(u32 x, s32 slice_height, const u8* tex, u32 texture_offs
 #define USE_ASM_RASTER
 
 #ifdef USE_ASM_RASTER
-void rasterise_line(u32 x, s32 slice_height, u32 texture_offset)
+void rasterise_line(u32 x, s32 slice_height, u32 texture_offset, u8* tex)
 {
 	int tex_inc_high, tex_inc_low;
 	
 	tex_inc_high = 64 / slice_height;
 	tex_inc_low = (((64 % slice_height) << 16) / slice_height);
 
-	asm_rasterise_line(x, slice_height, bricks_Bitmap, texture_offset, tex_inc_low, tex_inc_high);
+	asm_rasterise_line(x, slice_height, tex, texture_offset, tex_inc_low, tex_inc_high);
 }
 
 #else
@@ -227,7 +223,8 @@ void rasterise_line(u32 x, s32 slice_height, u32 texture_offset)
 void raycast()
 {
 	int i;
-	
+	char foo[100];
+
 	/* scan across the screen */
 	for(i=0; i < SCREEN_WIDTH; i++)
 	{
@@ -257,36 +254,36 @@ void raycast()
 			ay = (py / 64) * (64) - 1;
 			
 			/* Ya points up */
-			Ya = -64;
+			Ya = -FIXED(64);
 		} else {
 			/* get vertical co-ord of first grid intersection */
 			ay = (py / 64) * (64) + 64;
 
 			/* Ya points down */
-			Ya = 64;
+			Ya = FIXED(64);
 		}
 		
 		/* now get horiz co-ord of first grid intersection */
 		if(gba_tan(angle))
 		{
-			ax = px + ((py - ay) << 8) / gba_tan(angle);
+			ax = FIXED(px) + ((py - ay) << 16) / gba_tan(angle);
 
 			/* calculate X increment between intersections */
 			Xa = (-Ya << 8) / gba_tan(angle);
 		} else {
-			ax = 1 << 16; Xa = 1 << 16;
+			ax = 1 << 24; Xa = 1 << 24;
 		}
 		
 		/* loop until we hit a wall */
-		cur_x = ax; cur_y = ay;
+		cur_x = ax; cur_y = FIXED(ay);
 
 		TRACE("Tracing horizontally...\n");
-		TRACE("Starting at %d/%d, inc by %d/%d\n", ax, ay, Xa, Ya);
+		TRACE("Starting at %d/%d, inc by %d/%d\n", cur_x, cur_y, Xa, Ya);
 
 		while(1)
 		{
-			grid_x = cur_x / 64;
-			grid_y = cur_y / 64;
+			grid_x = cur_x / (256 * 64);
+			grid_y = cur_y / (256 * 64);
 
 			if(grid_x < 0 || grid_x > MAP_SIZE_X || grid_y < 0 || grid_y > MAP_SIZE_Y)
 				break;
@@ -301,6 +298,7 @@ void raycast()
 			cur_y += Ya;
 		}
 		TRACE("wall found!\n");
+		cur_x = cur_x >> 8; cur_y = cur_y >> 8;
 		wall_hit_x = cur_x; wall_hit_y = cur_y;
 		if(abs(px - cur_x) > abs(py - cur_y))
 		{
@@ -309,6 +307,7 @@ void raycast()
 			d1 = abs(((py - cur_y) << 8) / gba_sin(angle));
 		}
 		//d1 = pythag(px - cur_x, py - cur_y);
+		TRACE("distance: %d\n", d1);
 		
 		/* trace vertically */
 
@@ -319,30 +318,30 @@ void raycast()
 			ax = (px / 64) * (64) - 1;
 			
 			/* Xa points right */
-			Xa = -64;
+			Xa = -FIXED(64);
 		} else {
 			ax = (px / 64) * (64) + 64;
 			
 			/* Xa points left */
-			Xa = 64;
+			Xa = FIXED(64);
 		}
 		
 		/* now get horiz co-ord of first grid intersection */
-		ay = py + (((px - ax)*gba_tan(angle)) >> 8);
+		ay = FIXED(py) + (((px - ax)*gba_tan(angle)));
 
 		/* calculate X increment between intersections */
 		Ya = ((-Xa) * gba_tan(angle)) >> 8;
 
 		/* loop until we hit a wall */
-		cur_x = ax; cur_y = ay;
+		cur_x = FIXED(ax); cur_y = ay;
 
 		TRACE("Tracing vertically...\n");
 		TRACE("Starting at %d/%d, inc by %d/%d\n", ax, ay, Xa, Ya);
 		
 		while(1)
 		{
-			grid_x = cur_x / 64;
-			grid_y = cur_y / 64;
+			grid_x = cur_x >> 14;
+			grid_y = cur_y >> 14;
 
 			if(grid_x < 0 || grid_x >= MAP_SIZE_X || grid_y < 0 || grid_y >= MAP_SIZE_Y)
 				break;
@@ -360,6 +359,7 @@ void raycast()
 
 		/* check which of the horizontal trace or the vertical trace found the
 		 * nearer wall */
+		cur_x = cur_x >> 8; cur_y = cur_y >> 8;
 		if(abs(px - cur_x) > abs(py - cur_y))
 		{
 			d2 = abs(((px - cur_x) << 8) / gba_cos(angle));
@@ -367,6 +367,7 @@ void raycast()
 			d2 = abs(((py - cur_y) << 8)/ gba_sin(angle));
 		}
 		//d2 = pythag(px - cur_x, py - cur_y);
+		TRACE("distance: %d\n", d2);
 		
 		if(d2 < d1)
 		{
@@ -390,7 +391,8 @@ void raycast()
 		slice_height = FIXED(64 * PROJECTION_DISTANCE)  / distance;
 		
 		/* draw here! */
-		rasterise_line(i, slice_height, texture_offset);
+		rasterise_line(i, slice_height, texture_offset, walltextures_Bitmap + 
+			(map[((wall_hit_y/64) * MAP_SIZE_X) + (wall_hit_x/64)] - 1)*64*64);
 	}
 }
 
@@ -411,6 +413,24 @@ void player_move(s32 angle)
 		py = py - (((speed) * gba_sin(angle)) >> 8);
 }
 
+void trigtest()
+{
+	int a;
+	char foo[100];
+	for(a=0; a < 360; a+=10)
+	{
+		sprintf(foo, "sin(%3d): %f %f\n", a, sin(a * (M_PI / 180.0)), gba_sin(a*256) / 256.0); print(foo);
+	}
+	for(a=0; a < 360; a+=10)
+	{
+		sprintf(foo, "cos(%3d): %f %f\n", a, cos(a * (M_PI / 180.0)), gba_cos(a*256) / 256.0); print(foo);
+	}
+	for(a=0; a < 360; a+=10)
+	{
+		sprintf(foo, "tan(%3d): %f %f\n", a, tan(a * (M_PI / 180.0)), gba_tan(a*256) / 256.0); print(foo);
+	}
+}
+
 int AgbMain()
 {
 	int i;
@@ -423,7 +443,7 @@ int AgbMain()
 	//trigtest();
 	SetMode(MODE_4 | BG2_ENABLE);
 	for(i=0; i < 256; i++)
-		BGPaletteMem[i] = bricks_Palette[i];
+		BGPaletteMem[i] = walltextures_Palette[i];
 	
 	gba_initbank();
 
@@ -454,8 +474,7 @@ int AgbMain()
 		if(pa < 0) pa += 360;
 		if(pa > 360) pa -= 360;
 
-		/*sprintf(foo, "px: %4d py: %4d gx: %3d gy: %3d\n", px, py, px >> 6, py >> 6);
-		print(foo);*/
+		//sprintf(foo, "px: %4d py: %4d pa: %3d\n", px, py, pa); print(foo);
 
 		if(movement & MOVE_UP)
 		{
